@@ -1,22 +1,9 @@
 /*
-  Copyright ( C ) 2002 Rik Hemsley (  rikkus ) <rik@kde.org>
-  Copyright ( C ) 2002 Benjamin Meyer <ben-devel@meyerhome.net>
-  Copyright ( C ) 2002 Nadeem Hasan <nhasan@kde.org>
+    SPDX-FileCopyrightText: 2002 Rik Hemsley (  rikkus ) <rik@kde.org>
+    SPDX-FileCopyrightText: 2002 Benjamin Meyer <ben-devel@meyerhome.net>
+    SPDX-FileCopyrightText: 2002 Nadeem Hasan <nhasan@kde.org>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (  at your option ) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "httplookup.h"
@@ -115,7 +102,7 @@ namespace KCDDB
             case Success:
 
               if ( !block_ )
-                emit queryReady();
+                Q_EMIT queryReady();
               break;
 
             case MultipleRecordFound:
@@ -130,7 +117,7 @@ namespace KCDDB
                   result_ = Success;
 
                   if ( !block_ )
-                    emit queryReady();
+                    Q_EMIT queryReady();
                   break;
                 }
 
@@ -143,7 +130,7 @@ namespace KCDDB
             case ServerError:
             case NoRecordFound:
               if ( !block_ )
-                emit queryReady();
+                Q_EMIT queryReady();
 
               return;
               break;
@@ -171,7 +158,7 @@ namespace KCDDB
           }
 
           if ( !block_ )
-            emit readReady();
+            Q_EMIT readReady();
         }
 
         return;
